import { GetOrderWithStatus } from '../helpers/get-order-with-status.js';
import { createServiceRequestAction } from './request.js';
/**
 * Helper method to request a current order update.
 * If no order id is specified in the request and no current order exists
 * this will not create a new order.
 * This action could be used to resume the last known order on application
 * startup by providing an order id in the payload parameter
 *
 * All order modifications are done using the shoppingCart actions
 *
 * @export
 * @param {{
 *     payload: IGetOrderWithStatusRequest,
 *     serviceOptions?: IEvaServiceCallOptions;
 *   }} [params]
 * @returns
 */
export function createCurrentOrderUpdateAction(params) {
    const action = createServiceRequestAction({
        service: GetOrderWithStatus,
        stateOptions: {
            stateKey: 'currentOrder',
        },
        payload: params?.payload,
        customActionType: 'UPDATE',
        serviceOptions: params?.serviceOptions,
    });
    return action;
}
//# sourceMappingURL=current-order.js.map