import { Core } from '@springtree/eva-services-core';
import { v4 } from 'uuid';
import { createServiceRequestAction } from './request.js';
import { registerServicePromise, getServicePromiseChain } from '../promise.js';
/**
 * Helper method to update or unset the current user token
 *
 * @export
 * @param {string} [token='']
 * @returns
 */
export function createCurrentUserTokenAction(params = {}) {
    const guid = v4();
    const serviceContext = `CURRENT_USER_TOKEN:${guid}`;
    const chainContext = params.chainContext || `CURRENT_USER_TOKEN:CHAIN:${guid}`;
    // Create and register a promise for this call
    //
    const promise = registerServicePromise(serviceContext, chainContext);
    const promiseChain = getServicePromiseChain(chainContext);
    const tokenAction = {
        type: 'CURRENT_USER_TOKEN',
        payload: {
            serviceContext,
            chainContext,
            promise,
            token: params.token,
            promiseChain: promiseChain.promise,
        },
    };
    return tokenAction;
}
/**
 * Helper method to create a login request action for the current user
 *
 * @export
 * @param {EVA.Core.Login} request
 * @returns
 */
export function createCurrentUserLoginAction(params) {
    return createServiceRequestAction({
        service: Core.Login,
        stateOptions: { stateKey: 'login' },
        payload: params.data,
        chainContext: params.chainContext,
    });
}
/**
 * Helper method to create a logout request action for the current user
 *
 * @export
 * @param {EVA.Core.Logout} request
 * @returns
 */
export function createCurrentUserLogoutAction(params = {}) {
    return createServiceRequestAction({
        service: Core.Logout,
        stateOptions: { stateKey: 'logout' },
        payload: params.data,
        chainContext: params.chainContext,
    });
}
/**
 * Helper method to create an update request action for the current user
 *
 * @export
 * @param {EVA.Core.GetCurrentUser} request
 * @returns
 */
export function createCurrentUserUpdateAction(params = {}) {
    return createServiceRequestAction({
        service: Core.GetCurrentUser,
        stateOptions: { stateKey: 'currentUser' },
        payload: params.data,
        chainContext: params.chainContext,
    });
}
/**
 * Helper method to create a register user request action for the current user
 *
 * @export
 * @param {EVA.Core.CreateCustomer} request
 * @returns
 */
export function createCurrentUserRegisterAction(params) {
    return createServiceRequestAction({
        service: Core.CreateCustomer,
        stateOptions: { stateKey: 'register' },
        payload: params.request,
        chainContext: params.chainContext,
    });
}
//# sourceMappingURL=current-user.js.map