import { v4 } from 'uuid';
import { registerServicePromise, getServicePromiseChain } from '../promise.js';
/**
 * Helper method to create a typed EVA Service request action
 *
 * @export
 * @template SVC
 * @param {ICreateServiceRequestAction<SVC>} params The request action parameters
 * @returns
 */
export function createServiceRequestAction(params) {
    // Determine the state key name either by the service name or the provided
    // custom state key name
    //
    const chainService = params.chainService || new params.service().name;
    const serviceName = (params.stateOptions && params.stateOptions.stateKey) || chainService;
    // Create a unique id for this request
    //
    const guid = v4();
    const serviceContext = params.serviceContext || `${serviceName}:${guid}`;
    const chainContext = params.chainContext || `${serviceName}:CHAIN:${guid}`;
    // Create and register a promise for this call
    //
    const promise = registerServicePromise(serviceContext, chainContext);
    const promiseChain = getServicePromiseChain(chainContext);
    // Combine all supplied parameters into the action payload
    //
    const payload = {
        serviceContext,
        chainContext,
        chainService,
        promise,
        serviceOptions: params.serviceOptions,
        endpoint: params.endpoint,
        promiseChain: promiseChain.promise,
        data: params.payload,
    };
    // Build the final action object
    //
    const action = {
        payload,
        type: `${serviceName}:${params.customActionType || 'REQUEST'}`,
    };
    return action;
}
//# sourceMappingURL=request.js.map