import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { IEvaReduxStoreDefaultShape } from '../store.js';
import { IEvaServiceRequestAction, IStateOptions } from '../action/index.js';
/**
 * The extended product details request for the composite helper.
 * You can specify the availability request options but the product id will be
 * set from the details.
 * Same goes for configurable and bundle details to set included fields.
 * Product prices requests has no additional properties but they are exposed
 * here to be future proof
 *
 * @export
 * @interface IExtendedProductDetailsRequest
 */
export interface IExtendedProductDetailsRequest {
    details: EVA.Core.GetProductDetail;
    availability?: Partial<EVA.Core.GetProductAvailability>;
    bundleDetails?: Partial<EVA.Core.GetBundleProductDetails>;
    configurableDetails?: Partial<EVA.Core.GetConfigurableProductDetail>;
}
/**
 * The extended product details response with properties filled depending
 * on the type of product returned.
 * Availability and prices can be toggled when creating the logic
 *
 * @export
 * @interface IExtendedProductDetailsResponse
 */
export interface IExtendedProductDetailsResponse {
    details: EVA.Core.GetProductDetailResponse;
    availability?: EVA.Core.GetProductAvailabilityResponse;
    bundleDetails?: EVA.Core.GetBundleProductDetailResponse;
    configurableDetails?: EVA.Core.GetConfigurableProductDetailResponse;
    prices?: EVA.Core.GetProductPricesResponse;
}
/**
 * The composite service definition for the ExtendedProductDetails helper
 *
 * @export
 * @class ExtendedProductDetails
 * @implements {IEvaServiceDefinition}
 */
export declare class ExtendedProductDetails implements IEvaServiceDefinition {
    name: string;
    path: string;
    request?: IExtendedProductDetailsRequest;
    response?: IExtendedProductDetailsResponse;
}
/**
 * Additional options for the logic handling. Can be used to disable
 * additional request for prices and availability.
 *
 * @export
 * @interface IExtendedProductDetailsLogicOptions
 * @extends {IStateOptions}
 */
export interface IExtendedProductDetailsLogicOptions extends IStateOptions {
    /**
     * Availability is fetched by default but can be disabled with this option.
     * This options toggles availability for the product itself and all sellable
     * products that are configurable options or part of a bundle.
     *
     * @type {boolean}
     */
    disableAvailability?: boolean;
    /**
     * Product prices are fetched by default but can be disabled using this options
     *
     * @type {boolean}
     */
    disableProductPrices?: boolean;
}
/**
 * Composite service request logic builder for the ExtendedProductDetails helper
 *
 * @export
 * @template SHAPE
 * @param {IExtendedProductDetailsLogicOptions} [stateOptions]
 * @returns
 */
export declare function createExtendedProductDetailsLogic<SHAPE extends IEvaReduxStoreDefaultShape, SVC extends IEvaServiceDefinition = ExtendedProductDetails>(stateOptions?: IExtendedProductDetailsLogicOptions): import("redux-logic").Logic<SHAPE, IEvaServiceRequestAction<SVC, string>, object, object, object, string>[];
//# sourceMappingURL=extended-product-details.d.ts.map