import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { IEvaReduxStoreDefaultShape } from '../store.js';
import { IEvaServiceRequestAction, IStateOptions } from '../action/index.js';
/**
 * The product search request for the composite helper.
 * You can specify the availability request but the product ids will be overridden
 * from the search response
 *
 * @export
 * @interface IExtendedSearchProductsRequest
 */
export interface IExtendedSearchProductsRequest {
    search?: EVA.Core.SearchProducts;
    availability?: Partial<EVA.Core.GetProductAvailability>;
}
/**
 * The product search response with the product availability for any
 * products returned in the response.
 * If no products are found in the response the availability will not be present
 *
 * @export
 * @interface IExtendedSearchProductsResponse
 */
export interface IExtendedSearchProductsResponse {
    searchResult?: EVA.Core.SearchProductsResponse;
    availability?: EVA.Core.GetProductAvailabilityResponse;
    prices?: EVA.Core.GetProductPricesResponse;
}
/**
 * The composite service definition for the ExtendedSearchProducts helper
 *
 * @export
 * @class ExtendedSearchProducts
 * @implements {IEvaServiceDefinition}
 */
export declare class ExtendedSearchProducts implements IEvaServiceDefinition {
    name: string;
    path: string;
    request?: IExtendedSearchProductsRequest;
    response?: IExtendedSearchProductsResponse;
}
/**
 * Additional options for the logic handling. Can be used to disable
 * additional request for prices and availability.
 *
 * @export
 * @interface IExtendedSearchProductsLogicOptions
 * @extends {IStateOptions}
 */
export interface IExtendedSearchProductsLogicOptions extends IStateOptions {
    /**
     * Product prices are fetched by default but can be disabled using this options
     *
     * @type {boolean}
     */
    disableProductPrices?: boolean;
}
/**
 * Composite service request logic builder for the ExtendedSearchProducts helper
 *
 * @export
 * @template SHAPE
 * @param {IExtendedSearchProductsLogicOptions} [stateOptions]
 * @returns
 */
export declare function createExtendedSearchProductsLogic<SHAPE extends IEvaReduxStoreDefaultShape, SVC extends IEvaServiceDefinition = ExtendedSearchProducts>(stateOptions?: IExtendedSearchProductsLogicOptions): import("redux-logic").Logic<SHAPE, IEvaServiceRequestAction<SVC, string>, object, object, object, string>[];
//# sourceMappingURL=extended-search-products.d.ts.map