import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { IEvaReduxStoreDefaultShape } from '../store.js';
import { IEvaServiceRequestAction, IStateOptions } from '../action/index.js';
import { IOrderStatus } from './order-status.js';
import { IProductCountByType } from './product-count-by-type.js';
/**
 * The order with status requests.
 * The default required for level is set to 7 which are combined requirements for:
 * - Payment
 * - PlaceOrder
 * - ShipOrder
 *
 * @export
 * @interface IGetOrderWithStatusRequest
 */
export interface IGetOrderWithStatusRequest {
    order: EVA.Core.GetOrder;
}
/**
 * Combined response of the order with its required data.
 * Will also contain checkout (step) status and product counts
 *
 * @export
 * @interface IGetOrderWithStatusResponse
 */
export interface IGetOrderWithStatusResponse {
    order: EVA.Core.GetOrderResponse;
    status: IOrderStatus;
    productCount: IProductCountByType;
}
/**
 * The composite service definition for the GetOrderWithStatus helper
 *
 * @export
 * @class GetOrderWithStatus
 * @implements {IEvaServiceDefinition}
 */
export declare class GetOrderWithStatus implements IEvaServiceDefinition {
    name: string;
    path: string;
    request?: IGetOrderWithStatusRequest;
    response?: IGetOrderWithStatusResponse;
}
/**
 * Composite service request logic builder for the GetOrderWithStatus helper
 *
 * @export
 * @template SHAPE
 * @param {IGetOrderWithStatusLogicOptions} [stateOptions]
 * @returns
 */
export declare function createGetOrderWithStatusLogic<SHAPE extends IEvaReduxStoreDefaultShape>(stateOptions?: IStateOptions): import("redux-logic").Logic<SHAPE, IEvaServiceRequestAction<GetOrderWithStatus, string>, object, object, object, string>[];
//# sourceMappingURL=get-order-with-status.d.ts.map