import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { IEvaReduxStoreDefaultShape } from '../store.js';
import { IEvaServiceRequestAction, IStateOptions } from '../action/index.js';
import { IOrderStatus } from './order-status.js';
import { IProductCountByType } from './product-count-by-type.js';
/**
 * The shopping cart with status requests.
 * The default required for level is set to 7 which are combined requirements for:
 * - Payment
 * - PlaceOrder
 * - ShipOrder
 *
 * @export
 * @interface IGetShoppingCartWithStatusRequest
 */
export interface IGetShoppingCartWithStatusRequest {
    order: EVA.Core.GetShoppingCart;
}
/**
 * Combined response of the order with its required data.
 * Will also contain checkout (step) status and product counts
 *
 * @export
 * @interface IGetShoppingCartWithStatusResponse
 */
export interface IGetShoppingCartWithStatusResponse {
    order: EVA.Core.ShoppingCartResponse;
    status: IOrderStatus;
    productCount: IProductCountByType;
}
/**
 * The composite service definition for the GetShoppingCartWithStatus helper
 *
 * @export
 * @class GetShoppingCartWithStatus
 * @implements {IEvaServiceDefinition}
 */
export declare class GetShoppingCartWithStatus implements IEvaServiceDefinition {
    name: string;
    path: string;
    request?: IGetShoppingCartWithStatusRequest;
    response?: IGetShoppingCartWithStatusResponse;
}
/**
 * Composite service request logic builder for the GetShoppingCartWithStatus helper
 *
 * @export
 * @template SHAPE
 * @param {IGetShoppingCartWithStatusLogicOptions} [stateOptions]
 * @returns
 */
export declare function createGetShoppingCartWithStatusLogic<SHAPE extends IEvaReduxStoreDefaultShape>(stateOptions?: IStateOptions): import("redux-logic").Logic<SHAPE, IEvaServiceRequestAction<GetShoppingCartWithStatus, string>, object, object, object, string>[];
//# sourceMappingURL=get-shopping-cart-with-status.d.ts.map