import { logger } from '@springtree/eva-sdk-core-logger';
import { Interceptor, } from '@springtree/eva-sdk-core-service';
/**
 * This interceptor listens to all service responses for a new application token
 *
 * @export
 * @class AppTokenInterceptor
 */
export class ApplicationTokenInterceptor extends Interceptor {
    store;
    /**
     * Creates an instance of the EvaAvailableServices interceptor
     */
    constructor(store) {
        super('EVA:ReduxStoreApplicationToken');
        this.store = store;
        this.priority = 5;
    }
    /**
     * The response interceptor implementation.
     * Available as a public property for direct use
     * By returning a fetch Response we will prevent the service call from going out
     *
     * @type {IResponseInterceptor}
     */
    responseInterceptor = {
        hook: async (request, options, response) => {
            response.headers.forEach((value, name) => {
                if (`${name}`.toLowerCase() === 'EVA-App-Token'.toLowerCase()) {
                    // EVA Application tokens are usually returned on create order
                    // calls to provide secure access to anonymous orders
                    //
                    logger.log(`[EVA:SDK] persisting new application token ${value}`)();
                    const applicationTokenAction = {
                        type: 'APPLICATION_TOKEN',
                        payload: { token: value },
                    };
                    this.store.dispatch(applicationTokenAction);
                }
            });
            // IMPORTANT: Do not return a response here or any other interceptors will fail to fire
        },
    };
}
//# sourceMappingURL=application-token-interceptor.js.map