import { IEvaServiceCallOptions, EvaEndpoint } from '@springtree/eva-sdk-core-service';
import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { IEvaServiceResponseAction, IStateOptions } from '../action/index.js';
import { IEvaServiceState } from '../state/index.js';
import { IEvaReduxStoreDefaultShape } from '../store.js';
/**
 * The chain direction type values
 */
export type TChainDirection = 'REQUEST' | 'RESPONSE';
/**
 * The parameters to build the chain.
 * Chains can be used freely between requests and responses
 *
 * @export
 * @interface IChainOptions
 * @template SVC_TO
 * @template SVC_FROM
 */
export interface IChainOptions<SVC_FROM extends IEvaServiceDefinition, SVC_TO extends IEvaServiceDefinition> {
    from: {
        service: new () => SVC_FROM;
        type: TChainDirection;
        stateOptions?: IStateOptions;
    };
    to: {
        service: new () => SVC_TO;
        validate?: (state: IEvaServiceState<SVC_FROM>) => boolean;
        transform?: (state: IEvaServiceState<SVC_FROM>) => SVC_TO['request'] | void;
        endpoint?: EvaEndpoint;
        serviceOptions?: IEvaServiceCallOptions;
        stateOptions?: IStateOptions;
    };
}
/**
 * Creates a Redux logic to link 2 EVA service actions together
 *
 * @export
 * @template SHAPE The Redux store shape
 * @template SVC_FROM The EVA Service repository definition to link from
 * @template SVC_TO The EVA Service repository definition to link to
 * @param {IChainOptions<SVC_FROM, SVC_TO>} params The chain link configuration
 * @returns {Logic[]}
 */
export declare function createChainLogic<SHAPE extends IEvaReduxStoreDefaultShape, SVC_FROM extends IEvaServiceDefinition, SVC_TO extends IEvaServiceDefinition>(params: IChainOptions<SVC_FROM, SVC_TO>): import("redux-logic").Logic<SHAPE, IEvaServiceResponseAction<SVC_FROM, string>, object, object, object, string>[];
//# sourceMappingURL=chain.d.ts.map