export interface IEvaServicePromise<RES> {
    serviceContext: string;
    promise: Promise<RES>;
    resolve: (value?: RES) => void;
    reject: (reason?: unknown) => void;
    created_at: Date;
    resolved_at?: Date;
}
/**
 * Each promise chain has it's own promise that resolves when all the parts have
 * been collected and resolved
 *
 * @export
 * @interface IEvaServicePromiseChain
 */
export interface IEvaServicePromiseChain {
    parts: Promise<unknown>[];
    promise: Promise<unknown[]>;
}
/**
 * Registers a new EVA call promise
 *
 * @export
 * @template RES
 * @param {string} serviceContext The unique service context
 * @param {string} [chainContext] The unique chain this call belongs to
 * @returns {Promise<RES>}
 */
export declare function registerServicePromise<RES>(serviceContext: string, chainContext: string): Promise<RES | undefined>;
/**
 * Retrieve a promise using its context
 *
 * @export
 * @param {string} context
 * @returns IEvaServicePromise<any>|void
 */
export declare function getServicePromise(serviceContext: string): IEvaServicePromise<unknown>;
/**
 * Retrieves a promise chain using its context
 *
 * @export
 * @param {string} chainContext
 * @returns
 */
export declare function getServicePromiseChain(chainContext: string): IEvaServicePromiseChain;
//# sourceMappingURL=promise.d.ts.map