import { Reducer, Action } from 'redux';
/**
 * Format of customer actions provided for the reducer
 *
 * @export
 * @interface ICustomReducers
 * @template CST The customer state shape
 * @template ACT The customer action payload
 */
export interface ICustomReducers<CST, PAYLOAD = unknown> {
    [action: string]: Reducer<CST | null, Action<PAYLOAD>>;
}
/**
 * Creates a typed custom reducer function
 *
 * @export
 * @template CST
 * @template PAYLOAD
 * @param {((state: CST|undefined, action: Action<PAYLOAD>) => CST)} reducerFunc
 * @returns {Reducer<CST, Action<PAYLOAD>>}
 */
export declare function createCustomReducer<CST, ACTION extends Action<unknown>>(reducerFunc: (state: CST | undefined, action: ACTION) => CST): Reducer<CST, ACTION>;
/**
 * Combine all custom reducers for a single state key
 *
 * @export
 * @template CST The custom state shape
 * @param {ICreateCustomReducerOptions} options The required options for creating custom reducers
 * @returns {Reducer<IEvaServiceState<CST>|undefined>}
 */
export declare function combineCustomReducers<CST, PAYLOAD = unknown>(reducers: ICustomReducers<CST, PAYLOAD>): Reducer<CST | null, Action<PAYLOAD>>;
//# sourceMappingURL=custom.d.ts.map