/**
 * Creates a typed custom reducer function
 *
 * @export
 * @template CST
 * @template PAYLOAD
 * @param {((state: CST|undefined, action: Action<PAYLOAD>) => CST)} reducerFunc
 * @returns {Reducer<CST, Action<PAYLOAD>>}
 */
export function createCustomReducer(reducerFunc) {
    const customReducer = (state, action) => {
        return reducerFunc(state, action);
    };
    return customReducer;
}
/**
 * Combine all custom reducers for a single state key
 *
 * @export
 * @template CST The custom state shape
 * @param {ICreateCustomReducerOptions} options The required options for creating custom reducers
 * @returns {Reducer<IEvaServiceState<CST>|undefined>}
 */
export function combineCustomReducers(reducers) {
    const reducer = (state = null, action) => {
        const actionReducer = reducers[action.type];
        if (actionReducer) {
            return actionReducer(state, action);
        }
        return state;
    };
    return reducer;
}
//# sourceMappingURL=custom.js.map