import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { Reducer } from 'redux';
import { IEvaServiceState } from '../state/index.js';
/**
 * Additional options when creating a reducer
 *
 * @export
 * @interface ICreateServiceReducerOptions
 */
export interface ICreateServiceReducerOptions {
    /**
     * If a custom state key is specified the logic needs to know this.
     * Default behavior is for the state key to be the service name ex. `Core.Login`
     *
     * @type {string}
     */
    stateKey: string;
    /**
     * Indicates the error response should not removed any previous response
     */
    preserveResponseOnError?: boolean;
}
/**
 * Factory method for a generic EVA Service request and response reducer
 *
 * @export
 * @template SVC The service definition this state reducer is for
 * @param {new () => SVC} serviceDefinition The EVA Service registry definition
 * @param {ICreateServiceReducerOptions} [options] Creation options for the service reducer
 * @returns {(Reducer<IEvaServiceState<SVC>|undefined>)}
 */
export declare function createServiceReducer<SVC extends IEvaServiceDefinition>(serviceDefinition: new () => SVC, options?: ICreateServiceReducerOptions): Reducer<IEvaServiceState<SVC> | undefined>;
//# sourceMappingURL=service.d.ts.map