import { Core } from '@springtree/eva-services-core';
import { IEvaServiceState } from './service.js';
/**
 * The additional reduced current user properties
 * They are convenience fields that the check the currently logged in user type
 *
 * @export
 * @interface IEvaCurrentUserStatus
 */
export interface IEvaCurrentUserStatus {
    isAnonymous?: boolean;
    isLoggedIn?: boolean;
    isCustomer?: boolean;
    isEmployee?: boolean;
}
/**
 * The composite state for the current user
 *
 * @export
 * @interface IEvaCurrentUserState
 */
export interface IEvaReduxStoreCurrentUserShape {
    /**
     * The current user authentication token.
     * Can be provided at startup or set from CreateCustomer
     * Will be unset when expired.
     * Empty string is the default value and value when not set
     *
     * @type {string}
     */
    currentUserToken: string;
    /**
     * The current application token which will be the most recently returned
     * value from the EVA-App-Token. The eva-sdk-core-service package will
     * manage this value in-memory. The redux store will help persist the token
     * to storage for reloads.
     * Empty string is the default value and value when not set
     *
     * @type {string}
     */
    currentApplicationToken: string;
    /**
     * The most recent current user data
     *
     * @type {IEvaServiceState<Core.GetCurrentUser>}
     */
    currentUser?: IEvaServiceState<Core.GetCurrentUser>;
    /**
     * Convenience properties to determine current user status
     *
     * @type {IEvaCurrentUserStatus}
     */
    currentUserStatus?: IEvaCurrentUserStatus;
    /**
     * The most recent login call data
     *
     * @type {IEvaServiceState<Core.Login>}
     */
    login?: IEvaServiceState<Core.Login>;
    /**
     * The most recent logout call data
     *
     * @type {IEvaServiceState<Core.Logout>}
     */
    logout?: IEvaServiceState<Core.Logout>;
    /**
     * The most recent call to register a new user (customer)
     *
     * @type {IEvaServiceState<Core.CreateCustomer>}
     */
    register?: IEvaServiceState<Core.CreateCustomer>;
}
//# sourceMappingURL=current-user.d.ts.map