import { IEvaServiceDefinition } from '@springtree/eva-services-core';
import { IEvaServiceCallOptions } from '@springtree/eva-sdk-core-service';
/**
 * Generic EVA Service state for the Redux root state
 *
 * @export
 * @interface IEvaServiceState
 * @template T
 */
export interface IEvaServiceState<T extends IEvaServiceDefinition> {
    /**
     * The EVA service call data
     *
     * @type {T}
     */
    data: T;
    /**
     * The endpoint used for the service call this state belongs to
     *
     * @type {string}
     */
    endpoint?: string;
    /**
     * The EVA service options used for the call this state belongs to
     *
     * @type {IEvaServiceCallOptions}
     */
    serviceOptions?: IEvaServiceCallOptions;
    /**
     * The unique EVA service call context
     *
     * @type {string}
     */
    serviceContext?: string;
    /**
     * The unique service call chain context
     *
     * @type {string}
     */
    chainContext?: string;
    /**
     * The name of the service call that initially started the chain (if available)
     *
     * @type {string}
     */
    chainService?: string;
    /**
     * Indicator a request is pending
     *
     * @type {boolean}
     */
    fetching?: boolean;
    /**
     * The timestamp (ms) when the last request was made
     *
     * @type {number}
     */
    requestedAt?: number;
    /**
     * The timestamp (ms) when the last response was received
     *
     * @type {number}
     */
    responseAt?: number;
    /**
     * The error response that was received in the case of a failure
     *
     * @type {*}
     */
    error?: unknown;
}
//# sourceMappingURL=service.d.ts.map